# uneq

CLI application for removing EQ from video files. Supports Equaliser APO configs.

## usage

`uneq -i [video path] -e [eq config path]`

## limitations

Currently only supports PK (peak), LSC (low shelf) and HSC (high shelf) filter types
